Index: third_party/protobuf/csharp/src/Google.Protobuf.Test/IssuesTest.cs |
diff --git a/third_party/protobuf/python/google/protobuf/pyext/python_protobuf.cc b/third_party/protobuf/csharp/src/Google.Protobuf.Test/IssuesTest.cs |
similarity index 59% |
copy from third_party/protobuf/python/google/protobuf/pyext/python_protobuf.cc |
copy to third_party/protobuf/csharp/src/Google.Protobuf.Test/IssuesTest.cs |
index 1b1ab5d1dc7f4bf986884718c67d69a460232ada..a03500357f2aa45932b436d310ac329c532b3d5f 100644 |
--- a/third_party/protobuf/python/google/protobuf/pyext/python_protobuf.cc |
+++ b/third_party/protobuf/csharp/src/Google.Protobuf.Test/IssuesTest.cs |
@@ -1,63 +1,63 @@ |
-// Protocol Buffers - Google's data interchange format |
-// Copyright 2008 Google Inc. All rights reserved. |
-// http://code.google.com/p/protobuf/ |
-// |
-// Redistribution and use in source and binary forms, with or without |
-// modification, are permitted provided that the following conditions are |
-// met: |
-// |
-// * Redistributions of source code must retain the above copyright |
-// notice, this list of conditions and the following disclaimer. |
-// * Redistributions in binary form must reproduce the above |
-// copyright notice, this list of conditions and the following disclaimer |
-// in the documentation and/or other materials provided with the |
-// distribution. |
-// * Neither the name of Google Inc. nor the names of its |
-// contributors may be used to endorse or promote products derived from |
-// this software without specific prior written permission. |
-// |
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS |
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT |
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR |
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT |
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, |
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT |
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, |
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY |
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT |
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
- |
-// Author: qrczak@google.com (Marcin Kowalczyk) |
- |
-#include <google/protobuf/pyext/python_protobuf.h> |
- |
-namespace google { |
-namespace protobuf { |
-namespace python { |
- |
-static const Message* GetCProtoInsidePyProtoStub(PyObject* msg) { |
- return NULL; |
-} |
-static Message* MutableCProtoInsidePyProtoStub(PyObject* msg) { |
- return NULL; |
-} |
- |
-// This is initialized with a default, stub implementation. |
-// If python-google.protobuf.cc is loaded, the function pointer is overridden |
-// with a full implementation. |
-const Message* (*GetCProtoInsidePyProtoPtr)(PyObject* msg) = |
- GetCProtoInsidePyProtoStub; |
-Message* (*MutableCProtoInsidePyProtoPtr)(PyObject* msg) = |
- MutableCProtoInsidePyProtoStub; |
- |
-const Message* GetCProtoInsidePyProto(PyObject* msg) { |
- return GetCProtoInsidePyProtoPtr(msg); |
-} |
-Message* MutableCProtoInsidePyProto(PyObject* msg) { |
- return MutableCProtoInsidePyProtoPtr(msg); |
-} |
- |
-} // namespace python |
-} // namespace protobuf |
-} // namespace google |
+#region Copyright notice and license |
+// Protocol Buffers - Google's data interchange format |
+// Copyright 2008 Google Inc. All rights reserved. |
+// https://developers.google.com/protocol-buffers/ |
+// |
+// Redistribution and use in source and binary forms, with or without |
+// modification, are permitted provided that the following conditions are |
+// met: |
+// |
+// * Redistributions of source code must retain the above copyright |
+// notice, this list of conditions and the following disclaimer. |
+// * Redistributions in binary form must reproduce the above |
+// copyright notice, this list of conditions and the following disclaimer |
+// in the documentation and/or other materials provided with the |
+// distribution. |
+// * Neither the name of Google Inc. nor the names of its |
+// contributors may be used to endorse or promote products derived from |
+// this software without specific prior written permission. |
+// |
+// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS |
+// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT |
+// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR |
+// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT |
+// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, |
+// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT |
+// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, |
+// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY |
+// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT |
+// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
+// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
+#endregion |
+ |
+using Google.Protobuf.Reflection; |
+using UnitTest.Issues.TestProtos; |
+using NUnit.Framework; |
+ |
+ |
+namespace Google.Protobuf |
+{ |
+ /// <summary> |
+ /// Tests for issues which aren't easily compartmentalized into other unit tests. |
+ /// </summary> |
+ public class IssuesTest |
+ { |
+ // Issue 45 |
+ [Test] |
+ public void FieldCalledItem() |
+ { |
+ ItemField message = new ItemField { Item = 3 }; |
+ FieldDescriptor field = ItemField.Descriptor.FindFieldByName("item"); |
+ Assert.NotNull(field); |
+ Assert.AreEqual(3, (int)field.Accessor.GetValue(message)); |
+ } |
+ |
+ [Test] |
+ public void ReservedNames() |
+ { |
+ var message = new ReservedNames { Types_ = 10, Descriptor_ = 20 }; |
+ // Underscores aren't reflected in the JSON. |
+ Assert.AreEqual("{ \"types\": 10, \"descriptor\": 20 }", message.ToString()); |
+ } |
+ } |
+} |